# Generated by Django 4.1 on 2022-08-16 12:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('xperms', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='group',
            name='xperms',
            field=models.ManyToManyField(blank=True, related_name='xperms', to='xperms.perm', verbose_name='permissions'),
        ),
    ]
